package com.chelvc.framework.common.crypto;

import javax.crypto.Cipher;

/**
 * 密码处理器工厂接口
 *
 * @author Woody
 * @date 2024/6/25
 */
public interface CipherFactory {
    /**
     * 获取密钥
     *
     * @return 密钥
     */
    String getSecret();

    /**
     * 获取密码处理器
     *
     * @param mode 加解密模式
     * @return 密码处理器实例
     */
    Cipher getCipher(int mode);

    /**
     * 获取加密处理器
     *
     * @return 加密处理器
     */
    default Cipher getEncryptor() {
        return this.getCipher(Cipher.ENCRYPT_MODE);
    }

    /**
     * 获取解密处理器
     *
     * @return 解密处理器
     */
    default Cipher getDecrypter() {
        return this.getCipher(Cipher.DECRYPT_MODE);
    }
}
